# Onepanel AutoML v0.1.5

Onepanel's AutoML framework was built to improve the accuracy of your machine learning models and make them more accessible by automatically creating a data analysis pipeline that can include data pre-processing, feature selection, and feature engineering methods along with machine learning methods and parameter settings that are optimized for your data.

![automl flow](https://github.com/onepanelio/images/blob/master/automl.png?raw=true)

## Installation

```bash
pip install onepanel-automl
```

## Getting Started and Examples

- [Basics - Jupyter Notebook](examples/AutoML-basics-example.ipynb)
- [Titanic Kaggle Example - Jupyter Notebook](examples/AutoML-kaggle-example.ipynb)

## Running on Onepanel

To run AutoML on Onepanel, simply fork the following project:

https://c.onepanel.io/onepanel-demo/projects/automl

Then go to "Workspaces" and click "+Create", select any machine type and then choose either the TensorFlow or PyTorch environments.
